@@ -1,12 +1,11 @@
-from __future__ import absolute_import
-
 import linecache
-import tokenize
 from functools import partial
 from os.path import basename
 from os.path import exists
 from os.path import splitext
 from threading import current_thread
+from tokenize import TokenError
+from tokenize import generate_tokens
 
 from .const import SITE_PACKAGES_PATHS
 from .const import SYS_PREFIX_PATHS
@@ -18,10 +17,10 @@ from .util import get_func_in_mro
 from .util import get_main_thread
 from .util import if_same_code
 
-__all__ = 'Event',
+__all__ = ('Event',)
 
 
-class Event(object):
+class Event:
     """
     A wrapper object for Frame objects. Instances of this are passed to your custom functions or predicates.
 
@@ -35,6 +34,7 @@ class Event(object):
         tracer (:class:`hunter.tracer.Tracer`): The :class:`~hunter.tracer.Tracer` instance that created the event.
             Needed for the ``calls`` and ``depth`` fields.
     """
+
     frame = None
     kind = None
     arg = None
@@ -42,7 +42,16 @@ class Event(object):
     calls = None
     builtin = None
 
-    def __init__(self, frame, kind, arg, tracer=None, depth=None, calls=None, threading_support=MISSING):
+    def __init__(
+        self,
+        frame,
+        kind,
+        arg,
+        tracer=None,
+        depth=None,
+        calls=None,
+        threading_support=MISSING,
+    ):
         if tracer is None:
             if depth is None:
                 raise TypeError('Missing argument: depth (required because tracer was not given).')
@@ -107,19 +116,19 @@ class Event(object):
         self.detached = False
 
     def __repr__(self):
-        return '<Event kind=%r function=%r module=%r filename=%r lineno=%s>' % (
-            self.kind, self.function, self.module, self.filename, self.lineno
+        return '<Event kind={!r} function={!r} module={!r} filename={!r} lineno={}>'.format(
+            self.kind,
+            self.function,
+            self.module,
+            self.filename,
+            self.lineno,
         )
 
     def __eq__(self, other):
-        return (
-            type(self) == type(other) and
-            self.kind == other.kind and
-            self.depth == other.depth and
-            self.function == other.function and
-            self.module == other.module and
-            self.filename == other.filename
-        )
+        return self is other
+
+    def __reduce__(self):
+        raise TypeError("cannot pickle 'hunter.event.Event' object")
 
     def detach(self, value_filter=None):
         """
@@ -391,18 +400,25 @@ class Event(object):
             if self.kind == 'call' and self.code.co_name != '<module>':
                 lines = []
                 try:
-                    for _, token, _, _, line in tokenize.generate_tokens(partial(
-                        next,
-                        yield_lines(self.filename, self.frame.f_globals, self.lineno - 1, lines.append)
-                    )):
+                    for _, token, _, _, _ in generate_tokens(
+                        partial(
+                            next,
+                            yield_lines(
+                                self.filename,
+                                self.frame.f_globals,
+                                self.lineno - 1,
+                                lines.append,
+                            ),
+                        )
+                    ):
                         if token in ('def', 'class', 'lambda'):
                             return ''.join(lines)
-                except tokenize.TokenError:
+                except TokenError:
                     pass
 
             return linecache.getline(self.filename, self.lineno, self.frame.f_globals)
         except Exception as exc:
-            return '??? NO SOURCE: {!r}'.format(exc)
+            return f'??? NO SOURCE: {exc!r}'
 
     @cached_property
     def source(self):
@@ -414,21 +430,26 @@ class Event(object):
         :type: str
         """
         if self.filename.endswith(('.so', '.pyd')):
-            return '??? NO SOURCE: not reading binary {} file'.format(splitext(basename(self.filename))[1])
+            return f'??? NO SOURCE: not reading binary {splitext(basename(self.filename))[1]} file'
         try:
             return linecache.getline(self.filename, self.lineno, self.frame.f_globals)
         except Exception as exc:
-            return '??? NO SOURCE: {!r}'.format(exc)
+            return f'??? NO SOURCE: {exc!r}'
 
     __getitem__ = object.__getattribute__
 
 
-def yield_lines(filename, module_globals, start, collector,
-                limit=10,
-                leading_whitespace_re=LEADING_WHITESPACE_RE):
+def yield_lines(
+    filename,
+    module_globals,
+    start,
+    collector,
+    limit=10,
+    leading_whitespace_re=LEADING_WHITESPACE_RE,
+):
     dedent = None
     amount = 0
-    for line in linecache.getlines(filename, module_globals)[start:start + limit]:
+    for line in linecache.getlines(filename, module_globals)[start : start + limit]:
         if dedent is None:
             dedent = leading_whitespace_re.findall(line)
             dedent = dedent[0] if dedent else ''
